# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\x7f\n\x12MsgChannelOpenInit\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x33\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"A\n\x1aMsgChannelOpenInitResponse\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x89\x02\n\x11MsgChannelOpenTry\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x1f\n\x13previous_channel_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x33\n\x07\x63hannel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14\x63ounterparty_version\x18\x04 \x01(\t\x12\x12\n\nproof_init\x18\x05 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"@\n\x19MsgChannelOpenTryResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"\xe7\x01\n\x11MsgChannelOpenAck\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x1f\n\x17\x63ounterparty_channel_id\x18\x03 \x01(\t\x12\x1c\n\x14\x63ounterparty_version\x18\x04 \x01(\t\x12\x11\n\tproof_try\x18\x05 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgChannelOpenAckResponse\"\xac\x01\n\x15MsgChannelOpenConfirm\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x11\n\tproof_ack\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgChannelOpenConfirmResponse\"_\n\x13MsgChannelCloseInit\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1d\n\x1bMsgChannelCloseInitResponse\"\xae\x01\n\x16MsgChannelCloseConfirm\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x12\n\nproof_init\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgChannelCloseConfirmResponse\"\xb9\x01\n\rMsgRecvPacket\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x18\n\x10proof_commitment\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"V\n\x15MsgRecvPacketResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00\"\xd2\x01\n\nMsgTimeout\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x18\n\x10proof_unreceived\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x1a\n\x12next_sequence_recv\x18\x04 \x01(\x04\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"S\n\x12MsgTimeoutResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00\"\xee\x01\n\x11MsgTimeoutOnClose\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x18\n\x10proof_unreceived\x18\x02 \x01(\x0c\x12\x13\n\x0bproof_close\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x1a\n\x12next_sequence_recv\x18\x05 \x01(\x04\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"Z\n\x19MsgTimeoutOnCloseResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00\"\xd2\x01\n\x12MsgAcknowledgement\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\x12\x13\n\x0bproof_acked\x18\x03 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"[\n\x1aMsgAcknowledgementResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultType:\x04\x88\xa0\x1f\x00*\xa9\x01\n\x12ResponseResultType\x12\x35\n RESPONSE_RESULT_TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12\'\n\x19RESPONSE_RESULT_TYPE_NOOP\x10\x01\x1a\x08\x8a\x9d \x04NOOP\x12-\n\x1cRESPONSE_RESULT_TYPE_SUCCESS\x10\x02\x1a\x0b\x8a\x9d \x07SUCCESS\x1a\x04\x88\xa3\x1e\x00\x32\xb6\x08\n\x03Msg\x12k\n\x0f\x43hannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0e\x43hannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0e\x43hannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12\x43hannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a\x32.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10\x43hannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a\x30.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13\x43hannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a\x33.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12\".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0f\x41\x63knowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponse\x1a\x05\x80\xe7\xb0*\x01\x42;Z9github.com/cosmos/ibc-go/v7/modules/core/04-channel/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v7/modules/core/04-channel/types'
  _RESPONSERESULTTYPE._options = None
  _RESPONSERESULTTYPE._serialized_options = b'\210\243\036\000'
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._options = None
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._options = None
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._serialized_options = b'\212\235 \004NOOP'
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._options = None
  _RESPONSERESULTTYPE.values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._serialized_options = b'\212\235 \007SUCCESS'
  _MSGCHANNELOPENINIT.fields_by_name['channel']._options = None
  _MSGCHANNELOPENINIT.fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENINIT._options = None
  _MSGCHANNELOPENINIT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._serialized_options = b'\030\001'
  _MSGCHANNELOPENTRY.fields_by_name['channel']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENTRY.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENTRY._options = None
  _MSGCHANNELOPENTRY._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENACK.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENACK.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENACK._options = None
  _MSGCHANNELOPENACK._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENCONFIRM._options = None
  _MSGCHANNELOPENCONFIRM._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELCLOSEINIT._options = None
  _MSGCHANNELCLOSEINIT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._options = None
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELCLOSECONFIRM._options = None
  _MSGCHANNELCLOSECONFIRM._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGRECVPACKET.fields_by_name['packet']._options = None
  _MSGRECVPACKET.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGRECVPACKET.fields_by_name['proof_height']._options = None
  _MSGRECVPACKET.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGRECVPACKET._options = None
  _MSGRECVPACKET._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGRECVPACKETRESPONSE._options = None
  _MSGRECVPACKETRESPONSE._serialized_options = b'\210\240\037\000'
  _MSGTIMEOUT.fields_by_name['packet']._options = None
  _MSGTIMEOUT.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUT.fields_by_name['proof_height']._options = None
  _MSGTIMEOUT.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUT._options = None
  _MSGTIMEOUT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGTIMEOUTRESPONSE._options = None
  _MSGTIMEOUTRESPONSE._serialized_options = b'\210\240\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['packet']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUTONCLOSE._options = None
  _MSGTIMEOUTONCLOSE._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGTIMEOUTONCLOSERESPONSE._options = None
  _MSGTIMEOUTONCLOSERESPONSE._serialized_options = b'\210\240\037\000'
  _MSGACKNOWLEDGEMENT.fields_by_name['packet']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGACKNOWLEDGEMENT._options = None
  _MSGACKNOWLEDGEMENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGACKNOWLEDGEMENTRESPONSE._options = None
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_options = b'\210\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _RESPONSERESULTTYPE._serialized_start=2722
  _RESPONSERESULTTYPE._serialized_end=2891
  _MSGCHANNELOPENINIT._serialized_start=168
  _MSGCHANNELOPENINIT._serialized_end=295
  _MSGCHANNELOPENINITRESPONSE._serialized_start=297
  _MSGCHANNELOPENINITRESPONSE._serialized_end=362
  _MSGCHANNELOPENTRY._serialized_start=365
  _MSGCHANNELOPENTRY._serialized_end=630
  _MSGCHANNELOPENTRYRESPONSE._serialized_start=632
  _MSGCHANNELOPENTRYRESPONSE._serialized_end=696
  _MSGCHANNELOPENACK._serialized_start=699
  _MSGCHANNELOPENACK._serialized_end=930
  _MSGCHANNELOPENACKRESPONSE._serialized_start=932
  _MSGCHANNELOPENACKRESPONSE._serialized_end=959
  _MSGCHANNELOPENCONFIRM._serialized_start=962
  _MSGCHANNELOPENCONFIRM._serialized_end=1134
  _MSGCHANNELOPENCONFIRMRESPONSE._serialized_start=1136
  _MSGCHANNELOPENCONFIRMRESPONSE._serialized_end=1167
  _MSGCHANNELCLOSEINIT._serialized_start=1169
  _MSGCHANNELCLOSEINIT._serialized_end=1264
  _MSGCHANNELCLOSEINITRESPONSE._serialized_start=1266
  _MSGCHANNELCLOSEINITRESPONSE._serialized_end=1295
  _MSGCHANNELCLOSECONFIRM._serialized_start=1298
  _MSGCHANNELCLOSECONFIRM._serialized_end=1472
  _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_start=1474
  _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_end=1506
  _MSGRECVPACKET._serialized_start=1509
  _MSGRECVPACKET._serialized_end=1694
  _MSGRECVPACKETRESPONSE._serialized_start=1696
  _MSGRECVPACKETRESPONSE._serialized_end=1782
  _MSGTIMEOUT._serialized_start=1785
  _MSGTIMEOUT._serialized_end=1995
  _MSGTIMEOUTRESPONSE._serialized_start=1997
  _MSGTIMEOUTRESPONSE._serialized_end=2080
  _MSGTIMEOUTONCLOSE._serialized_start=2083
  _MSGTIMEOUTONCLOSE._serialized_end=2321
  _MSGTIMEOUTONCLOSERESPONSE._serialized_start=2323
  _MSGTIMEOUTONCLOSERESPONSE._serialized_end=2413
  _MSGACKNOWLEDGEMENT._serialized_start=2416
  _MSGACKNOWLEDGEMENT._serialized_end=2626
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_start=2628
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_end=2719
  _MSG._serialized_start=2894
  _MSG._serialized_end=3972
# @@protoc_insertion_point(module_scope)
