# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v2/solomachine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v2/solomachine.proto\x12\x1fibc.lightclients.solomachine.v2\x1a\'ibc/core/connection/v1/connection.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xa7\x01\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\tis_frozen\x18\x02 \x01(\x08\x12H\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v2.ConsensusState\x12#\n\x1b\x61llow_update_after_proposal\x18\x04 \x01(\x08:\x04\x88\xa0\x1f\x00\"h\n\x0e\x43onsensusState\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"\x8d\x01\n\x06Header\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12,\n\x0enew_public_key\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0fnew_diversifier\x18\x05 \x01(\t:\x04\x88\xa0\x1f\x00\"\xcd\x01\n\x0cMisbehaviour\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12H\n\rsignature_one\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v2.SignatureAndData\x12H\n\rsignature_two\x18\x04 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v2.SignatureAndData:\x04\x88\xa0\x1f\x00\"\x8a\x01\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12<\n\tdata_type\x18\x02 \x01(\x0e\x32).ibc.lightclients.solomachine.v2.DataType\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"K\n\x18TimestampedSignatureData\x12\x16\n\x0esignature_data\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"\x97\x01\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12<\n\tdata_type\x18\x04 \x01(\x0e\x32).ibc.lightclients.solomachine.v2.DataType\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"V\n\nHeaderData\x12)\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0fnew_diversifier\x18\x02 \x01(\t:\x04\x88\xa0\x1f\x00\"Q\n\x0f\x43lientStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12*\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x04\x88\xa0\x1f\x00\"W\n\x12\x43onsensusStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x04\x88\xa0\x1f\x00\"d\n\x13\x43onnectionStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEnd:\x04\x88\xa0\x1f\x00\"U\n\x10\x43hannelStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.Channel:\x04\x88\xa0\x1f\x00\"8\n\x14PacketCommitmentData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x12\n\ncommitment\x18\x02 \x01(\x0c\"B\n\x19PacketAcknowledgementData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\"(\n\x18PacketReceiptAbsenceData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\";\n\x14NextSequenceRecvData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x15\n\rnext_seq_recv\x18\x02 \x01(\x04*\x8c\x04\n\x08\x44\x61taType\x12\x38\n#DATA_TYPE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12&\n\x16\x44\x41TA_TYPE_CLIENT_STATE\x10\x01\x1a\n\x8a\x9d \x06\x43LIENT\x12,\n\x19\x44\x41TA_TYPE_CONSENSUS_STATE\x10\x02\x1a\r\x8a\x9d \tCONSENSUS\x12.\n\x1a\x44\x41TA_TYPE_CONNECTION_STATE\x10\x03\x1a\x0e\x8a\x9d \nCONNECTION\x12(\n\x17\x44\x41TA_TYPE_CHANNEL_STATE\x10\x04\x1a\x0b\x8a\x9d \x07\x43HANNEL\x12\x35\n\x1b\x44\x41TA_TYPE_PACKET_COMMITMENT\x10\x05\x1a\x14\x8a\x9d \x10PACKETCOMMITMENT\x12?\n DATA_TYPE_PACKET_ACKNOWLEDGEMENT\x10\x06\x1a\x19\x8a\x9d \x15PACKETACKNOWLEDGEMENT\x12>\n DATA_TYPE_PACKET_RECEIPT_ABSENCE\x10\x07\x1a\x18\x8a\x9d \x14PACKETRECEIPTABSENCE\x12\x36\n\x1c\x44\x41TA_TYPE_NEXT_SEQUENCE_RECV\x10\x08\x1a\x14\x8a\x9d \x10NEXTSEQUENCERECV\x12 \n\x10\x44\x41TA_TYPE_HEADER\x10\t\x1a\n\x8a\x9d \x06HEADER\x1a\x04\x88\xa3\x1e\x00\x42\x42Z@github.com/cosmos/ibc-go/v7/modules/core/02-client/migrations/v7b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v2.solomachine_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z@github.com/cosmos/ibc-go/v7/modules/core/02-client/migrations/v7'
  _DATATYPE._options = None
  _DATATYPE._serialized_options = b'\210\243\036\000'
  _DATATYPE.values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _DATATYPE.values_by_name["DATA_TYPE_CLIENT_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CLIENT_STATE"]._serialized_options = b'\212\235 \006CLIENT'
  _DATATYPE.values_by_name["DATA_TYPE_CONSENSUS_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CONSENSUS_STATE"]._serialized_options = b'\212\235 \tCONSENSUS'
  _DATATYPE.values_by_name["DATA_TYPE_CONNECTION_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CONNECTION_STATE"]._serialized_options = b'\212\235 \nCONNECTION'
  _DATATYPE.values_by_name["DATA_TYPE_CHANNEL_STATE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_CHANNEL_STATE"]._serialized_options = b'\212\235 \007CHANNEL'
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._serialized_options = b'\212\235 \020PACKETCOMMITMENT'
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._serialized_options = b'\212\235 \025PACKETACKNOWLEDGEMENT'
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._serialized_options = b'\212\235 \024PACKETRECEIPTABSENCE'
  _DATATYPE.values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._serialized_options = b'\212\235 \020NEXTSEQUENCERECV'
  _DATATYPE.values_by_name["DATA_TYPE_HEADER"]._options = None
  _DATATYPE.values_by_name["DATA_TYPE_HEADER"]._serialized_options = b'\212\235 \006HEADER'
  _CLIENTSTATE._options = None
  _CLIENTSTATE._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATE._options = None
  _CONSENSUSSTATE._serialized_options = b'\210\240\037\000'
  _HEADER._options = None
  _HEADER._serialized_options = b'\210\240\037\000'
  _MISBEHAVIOUR._options = None
  _MISBEHAVIOUR._serialized_options = b'\210\240\037\000'
  _SIGNATUREANDDATA._options = None
  _SIGNATUREANDDATA._serialized_options = b'\210\240\037\000'
  _TIMESTAMPEDSIGNATUREDATA._options = None
  _TIMESTAMPEDSIGNATUREDATA._serialized_options = b'\210\240\037\000'
  _SIGNBYTES._options = None
  _SIGNBYTES._serialized_options = b'\210\240\037\000'
  _HEADERDATA._options = None
  _HEADERDATA._serialized_options = b'\210\240\037\000'
  _CLIENTSTATEDATA._options = None
  _CLIENTSTATEDATA._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATEDATA._options = None
  _CONSENSUSSTATEDATA._serialized_options = b'\210\240\037\000'
  _CONNECTIONSTATEDATA._options = None
  _CONNECTIONSTATEDATA._serialized_options = b'\210\240\037\000'
  _CHANNELSTATEDATA._options = None
  _CHANNELSTATEDATA._serialized_options = b'\210\240\037\000'
  _DATATYPE._serialized_start=1890
  _DATATYPE._serialized_end=2414
  _CLIENTSTATE._serialized_start=212
  _CLIENTSTATE._serialized_end=379
  _CONSENSUSSTATE._serialized_start=381
  _CONSENSUSSTATE._serialized_end=485
  _HEADER._serialized_start=488
  _HEADER._serialized_end=629
  _MISBEHAVIOUR._serialized_start=632
  _MISBEHAVIOUR._serialized_end=837
  _SIGNATUREANDDATA._serialized_start=840
  _SIGNATUREANDDATA._serialized_end=978
  _TIMESTAMPEDSIGNATUREDATA._serialized_start=980
  _TIMESTAMPEDSIGNATUREDATA._serialized_end=1055
  _SIGNBYTES._serialized_start=1058
  _SIGNBYTES._serialized_end=1209
  _HEADERDATA._serialized_start=1211
  _HEADERDATA._serialized_end=1297
  _CLIENTSTATEDATA._serialized_start=1299
  _CLIENTSTATEDATA._serialized_end=1380
  _CONSENSUSSTATEDATA._serialized_start=1382
  _CONSENSUSSTATEDATA._serialized_end=1469
  _CONNECTIONSTATEDATA._serialized_start=1471
  _CONNECTIONSTATEDATA._serialized_end=1571
  _CHANNELSTATEDATA._serialized_start=1573
  _CHANNELSTATEDATA._serialized_end=1658
  _PACKETCOMMITMENTDATA._serialized_start=1660
  _PACKETCOMMITMENTDATA._serialized_end=1716
  _PACKETACKNOWLEDGEMENTDATA._serialized_start=1718
  _PACKETACKNOWLEDGEMENTDATA._serialized_end=1784
  _PACKETRECEIPTABSENCEDATA._serialized_start=1786
  _PACKETRECEIPTABSENCEDATA._serialized_end=1826
  _NEXTSEQUENCERECVDATA._serialized_start=1828
  _NEXTSEQUENCERECVDATA._serialized_end=1887
# @@protoc_insertion_point(module_scope)
