# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/module/v1/module.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/params/module/v1/module.proto\x12\x17\x63osmos.params.module.v1\x1a cosmos/app/v1alpha1/module.proto\"7\n\x06Module:-\xba\xc0\x96\xda\x01\'\n%github.com/cosmos/cosmos-sdk/x/paramsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.module.v1.module_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODULE._options = None
  _MODULE._serialized_options = b'\272\300\226\332\001\'\n%github.com/cosmos/cosmos-sdk/x/params'
  _MODULE._serialized_start=99
  _MODULE._serialized_end=154
# @@protoc_insertion_point(module_scope)
