# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmwasm/wasm/v1/tx.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xb7\x01\n\x0cMsgStoreCode\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12(\n\x0ewasm_byte_code\x18\x02 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig:!\x8a\xe7\xb0*\x11wasm/MsgStoreCode\x82\xe7\xb0*\x06senderJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"E\n\x14MsgStoreCodeResponse\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\x0c\"\x96\x02\n\x16MsgInstantiateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x61\x64min\x18\x02 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x04 \x01(\t\x12#\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:+\x8a\xe7\xb0*\x1bwasm/MsgInstantiateContract\x82\xe7\xb0*\x06sender\"?\n\x1eMsgInstantiateContractResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xb7\x02\n\x17MsgInstantiateContract2\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x61\x64min\x18\x02 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x04 \x01(\t\x12#\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x0c\n\x04salt\x18\x07 \x01(\x0c\x12\x0f\n\x07\x66ix_msg\x18\x08 \x01(\x08:,\x8a\xe7\xb0*\x1cwasm/MsgInstantiateContract2\x82\xe7\xb0*\x06sender\"@\n\x1fMsgInstantiateContract2Response\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xe5\x01\n\x12MsgExecuteContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12#\n\x03msg\x18\x03 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\'\x8a\xe7\xb0*\x17wasm/MsgExecuteContract\x82\xe7\xb0*\x06sender\"*\n\x1aMsgExecuteContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xa1\x01\n\x12MsgMigrateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:\'\x8a\xe7\xb0*\x17wasm/MsgMigrateContract\x82\xe7\xb0*\x06sender\"*\n\x1aMsgMigrateContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"j\n\x0eMsgUpdateAdmin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tnew_admin\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t:#\x8a\xe7\xb0*\x13wasm/MsgUpdateAdmin\x82\xe7\xb0*\x06sender\"\x18\n\x16MsgUpdateAdminResponse\"U\n\rMsgClearAdmin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t:\"\x8a\xe7\xb0*\x12wasm/MsgClearAdmin\x82\xe7\xb0*\x06sender\"\x17\n\x15MsgClearAdminResponse\"\xbe\x01\n\x1aMsgUpdateInstantiateConfig\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x42\n\x1anew_instantiate_permission\x18\x03 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig:/\x8a\xe7\xb0*\x1fwasm/MsgUpdateInstantiateConfig\x82\xe7\xb0*\x06sender\"$\n\"MsgUpdateInstantiateConfigResponse\"\x9c\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\'\x8a\xe7\xb0*\x14wasm/MsgUpdateParams\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"\x9e\x01\n\x0fMsgSudoContract\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12#\n\x03msg\x18\x03 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:\'\x8a\xe7\xb0*\x14wasm/MsgSudoContract\x82\xe7\xb0*\tauthority\"\'\n\x17MsgSudoContractResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x91\x01\n\x0bMsgPinCodes\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x08\x63ode_ids\x18\x02 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\":#\x8a\xe7\xb0*\x10wasm/MsgPinCodes\x82\xe7\xb0*\tauthority\"\x15\n\x13MsgPinCodesResponse\"\x95\x01\n\rMsgUnpinCodes\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x08\x63ode_ids\x18\x02 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\":%\x8a\xe7\xb0*\x12wasm/MsgUnpinCodes\x82\xe7\xb0*\tauthority\"\x17\n\x15MsgUnpinCodesResponse\"\xdb\x03\n\x1eMsgStoreAndInstantiateContract\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12(\n\x0ewasm_byte_code\x18\x03 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x04 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig\x12\x12\n\nunpin_code\x18\x05 \x01(\x08\x12\r\n\x05\x61\x64min\x18\x06 \x01(\t\x12\r\n\x05label\x18\x07 \x01(\t\x12#\n\x03msg\x18\x08 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\t \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0f\n\x07\x62uilder\x18\x0b \x01(\t\x12\x11\n\tcode_hash\x18\x0c \x01(\x0c:6\x8a\xe7\xb0*#wasm/MsgStoreAndInstantiateContract\x82\xe7\xb0*\tauthority\"G\n&MsgStoreAndInstantiateContractResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x32\xb5\n\n\x03Msg\x12S\n\tStoreCode\x12\x1e.cosmwasm.wasm.v1.MsgStoreCode\x1a&.cosmwasm.wasm.v1.MsgStoreCodeResponse\x12q\n\x13InstantiateContract\x12(.cosmwasm.wasm.v1.MsgInstantiateContract\x1a\x30.cosmwasm.wasm.v1.MsgInstantiateContractResponse\x12t\n\x14InstantiateContract2\x12).cosmwasm.wasm.v1.MsgInstantiateContract2\x1a\x31.cosmwasm.wasm.v1.MsgInstantiateContract2Response\x12\x65\n\x0f\x45xecuteContract\x12$.cosmwasm.wasm.v1.MsgExecuteContract\x1a,.cosmwasm.wasm.v1.MsgExecuteContractResponse\x12\x65\n\x0fMigrateContract\x12$.cosmwasm.wasm.v1.MsgMigrateContract\x1a,.cosmwasm.wasm.v1.MsgMigrateContractResponse\x12Y\n\x0bUpdateAdmin\x12 .cosmwasm.wasm.v1.MsgUpdateAdmin\x1a(.cosmwasm.wasm.v1.MsgUpdateAdminResponse\x12V\n\nClearAdmin\x12\x1f.cosmwasm.wasm.v1.MsgClearAdmin\x1a\'.cosmwasm.wasm.v1.MsgClearAdminResponse\x12}\n\x17UpdateInstantiateConfig\x12,.cosmwasm.wasm.v1.MsgUpdateInstantiateConfig\x1a\x34.cosmwasm.wasm.v1.MsgUpdateInstantiateConfigResponse\x12\\\n\x0cUpdateParams\x12!.cosmwasm.wasm.v1.MsgUpdateParams\x1a).cosmwasm.wasm.v1.MsgUpdateParamsResponse\x12\\\n\x0cSudoContract\x12!.cosmwasm.wasm.v1.MsgSudoContract\x1a).cosmwasm.wasm.v1.MsgSudoContractResponse\x12P\n\x08PinCodes\x12\x1d.cosmwasm.wasm.v1.MsgPinCodes\x1a%.cosmwasm.wasm.v1.MsgPinCodesResponse\x12V\n\nUnpinCodes\x12\x1f.cosmwasm.wasm.v1.MsgUnpinCodes\x1a\'.cosmwasm.wasm.v1.MsgUnpinCodesResponse\x12\x89\x01\n\x1bStoreAndInstantiateContract\x12\x30.cosmwasm.wasm.v1.MsgStoreAndInstantiateContract\x1a\x38.cosmwasm.wasm.v1.MsgStoreAndInstantiateContractResponseB,Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000'
  _MSGSTORECODE.fields_by_name['wasm_byte_code']._options = None
  _MSGSTORECODE.fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _MSGSTORECODE._options = None
  _MSGSTORECODE._serialized_options = b'\212\347\260*\021wasm/MsgStoreCode\202\347\260*\006sender'
  _MSGSTORECODERESPONSE.fields_by_name['code_id']._options = None
  _MSGSTORECODERESPONSE.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGINSTANTIATECONTRACT.fields_by_name['code_id']._options = None
  _MSGINSTANTIATECONTRACT.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGINSTANTIATECONTRACT.fields_by_name['msg']._options = None
  _MSGINSTANTIATECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGINSTANTIATECONTRACT.fields_by_name['funds']._options = None
  _MSGINSTANTIATECONTRACT.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGINSTANTIATECONTRACT._options = None
  _MSGINSTANTIATECONTRACT._serialized_options = b'\212\347\260*\033wasm/MsgInstantiateContract\202\347\260*\006sender'
  _MSGINSTANTIATECONTRACT2.fields_by_name['code_id']._options = None
  _MSGINSTANTIATECONTRACT2.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGINSTANTIATECONTRACT2.fields_by_name['msg']._options = None
  _MSGINSTANTIATECONTRACT2.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGINSTANTIATECONTRACT2.fields_by_name['funds']._options = None
  _MSGINSTANTIATECONTRACT2.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGINSTANTIATECONTRACT2._options = None
  _MSGINSTANTIATECONTRACT2._serialized_options = b'\212\347\260*\034wasm/MsgInstantiateContract2\202\347\260*\006sender'
  _MSGEXECUTECONTRACT.fields_by_name['msg']._options = None
  _MSGEXECUTECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGEXECUTECONTRACT.fields_by_name['funds']._options = None
  _MSGEXECUTECONTRACT.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGEXECUTECONTRACT._options = None
  _MSGEXECUTECONTRACT._serialized_options = b'\212\347\260*\027wasm/MsgExecuteContract\202\347\260*\006sender'
  _MSGMIGRATECONTRACT.fields_by_name['code_id']._options = None
  _MSGMIGRATECONTRACT.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGMIGRATECONTRACT.fields_by_name['msg']._options = None
  _MSGMIGRATECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGMIGRATECONTRACT._options = None
  _MSGMIGRATECONTRACT._serialized_options = b'\212\347\260*\027wasm/MsgMigrateContract\202\347\260*\006sender'
  _MSGUPDATEADMIN._options = None
  _MSGUPDATEADMIN._serialized_options = b'\212\347\260*\023wasm/MsgUpdateAdmin\202\347\260*\006sender'
  _MSGCLEARADMIN._options = None
  _MSGCLEARADMIN._serialized_options = b'\212\347\260*\022wasm/MsgClearAdmin\202\347\260*\006sender'
  _MSGUPDATEINSTANTIATECONFIG.fields_by_name['code_id']._options = None
  _MSGUPDATEINSTANTIATECONFIG.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MSGUPDATEINSTANTIATECONFIG._options = None
  _MSGUPDATEINSTANTIATECONFIG._serialized_options = b'\212\347\260*\037wasm/MsgUpdateInstantiateConfig\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\212\347\260*\024wasm/MsgUpdateParams\202\347\260*\tauthority'
  _MSGSUDOCONTRACT.fields_by_name['authority']._options = None
  _MSGSUDOCONTRACT.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSUDOCONTRACT.fields_by_name['msg']._options = None
  _MSGSUDOCONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGSUDOCONTRACT._options = None
  _MSGSUDOCONTRACT._serialized_options = b'\212\347\260*\024wasm/MsgSudoContract\202\347\260*\tauthority'
  _MSGPINCODES.fields_by_name['authority']._options = None
  _MSGPINCODES.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGPINCODES.fields_by_name['code_ids']._options = None
  _MSGPINCODES.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _MSGPINCODES._options = None
  _MSGPINCODES._serialized_options = b'\212\347\260*\020wasm/MsgPinCodes\202\347\260*\tauthority'
  _MSGUNPINCODES.fields_by_name['authority']._options = None
  _MSGUNPINCODES.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUNPINCODES.fields_by_name['code_ids']._options = None
  _MSGUNPINCODES.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _MSGUNPINCODES._options = None
  _MSGUNPINCODES._serialized_options = b'\212\347\260*\022wasm/MsgUnpinCodes\202\347\260*\tauthority'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['authority']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['wasm_byte_code']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['msg']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['funds']._options = None
  _MSGSTOREANDINSTANTIATECONTRACT.fields_by_name['funds']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGSTOREANDINSTANTIATECONTRACT._options = None
  _MSGSTOREANDINSTANTIATECONTRACT._serialized_options = b'\212\347\260*#wasm/MsgStoreAndInstantiateContract\202\347\260*\tauthority'
  _MSGSTORECODE._serialized_start=203
  _MSGSTORECODE._serialized_end=386
  _MSGSTORECODERESPONSE._serialized_start=388
  _MSGSTORECODERESPONSE._serialized_end=457
  _MSGINSTANTIATECONTRACT._serialized_start=460
  _MSGINSTANTIATECONTRACT._serialized_end=738
  _MSGINSTANTIATECONTRACTRESPONSE._serialized_start=740
  _MSGINSTANTIATECONTRACTRESPONSE._serialized_end=803
  _MSGINSTANTIATECONTRACT2._serialized_start=806
  _MSGINSTANTIATECONTRACT2._serialized_end=1117
  _MSGINSTANTIATECONTRACT2RESPONSE._serialized_start=1119
  _MSGINSTANTIATECONTRACT2RESPONSE._serialized_end=1183
  _MSGEXECUTECONTRACT._serialized_start=1186
  _MSGEXECUTECONTRACT._serialized_end=1415
  _MSGEXECUTECONTRACTRESPONSE._serialized_start=1417
  _MSGEXECUTECONTRACTRESPONSE._serialized_end=1459
  _MSGMIGRATECONTRACT._serialized_start=1462
  _MSGMIGRATECONTRACT._serialized_end=1623
  _MSGMIGRATECONTRACTRESPONSE._serialized_start=1625
  _MSGMIGRATECONTRACTRESPONSE._serialized_end=1667
  _MSGUPDATEADMIN._serialized_start=1669
  _MSGUPDATEADMIN._serialized_end=1775
  _MSGUPDATEADMINRESPONSE._serialized_start=1777
  _MSGUPDATEADMINRESPONSE._serialized_end=1801
  _MSGCLEARADMIN._serialized_start=1803
  _MSGCLEARADMIN._serialized_end=1888
  _MSGCLEARADMINRESPONSE._serialized_start=1890
  _MSGCLEARADMINRESPONSE._serialized_end=1913
  _MSGUPDATEINSTANTIATECONFIG._serialized_start=1916
  _MSGUPDATEINSTANTIATECONFIG._serialized_end=2106
  _MSGUPDATEINSTANTIATECONFIGRESPONSE._serialized_start=2108
  _MSGUPDATEINSTANTIATECONFIGRESPONSE._serialized_end=2144
  _MSGUPDATEPARAMS._serialized_start=2147
  _MSGUPDATEPARAMS._serialized_end=2303
  _MSGUPDATEPARAMSRESPONSE._serialized_start=2305
  _MSGUPDATEPARAMSRESPONSE._serialized_end=2330
  _MSGSUDOCONTRACT._serialized_start=2333
  _MSGSUDOCONTRACT._serialized_end=2491
  _MSGSUDOCONTRACTRESPONSE._serialized_start=2493
  _MSGSUDOCONTRACTRESPONSE._serialized_end=2532
  _MSGPINCODES._serialized_start=2535
  _MSGPINCODES._serialized_end=2680
  _MSGPINCODESRESPONSE._serialized_start=2682
  _MSGPINCODESRESPONSE._serialized_end=2703
  _MSGUNPINCODES._serialized_start=2706
  _MSGUNPINCODES._serialized_end=2855
  _MSGUNPINCODESRESPONSE._serialized_start=2857
  _MSGUNPINCODESRESPONSE._serialized_end=2880
  _MSGSTOREANDINSTANTIATECONTRACT._serialized_start=2883
  _MSGSTOREANDINSTANTIATECONTRACT._serialized_end=3358
  _MSGSTOREANDINSTANTIATECONTRACTRESPONSE._serialized_start=3360
  _MSGSTOREANDINSTANTIATECONTRACTRESPONSE._serialized_end=3431
  _MSG._serialized_start=3434
  _MSG._serialized_end=4767
# @@protoc_insertion_point(module_scope)
