# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/ack.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/applications/fee/v1/ack.proto\x12\x17ibc.applications.fee.v1\"{\n\x1bIncentivizedAcknowledgement\x12\x1b\n\x13\x61pp_acknowledgement\x18\x01 \x01(\x0c\x12\x1f\n\x17\x66orward_relayer_address\x18\x02 \x01(\t\x12\x1e\n\x16underlying_app_success\x18\x03 \x01(\x08\x42\x37Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.ack_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _INCENTIVIZEDACKNOWLEDGEMENT._serialized_start=62
  _INCENTIVIZEDACKNOWLEDGEMENT._serialized_end=185
# @@protoc_insertion_point(module_scope)
