# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.interchain_accounts.v1 import packet_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_v1_dot_packet__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ibc/applications/interchain_accounts/controller/v1/tx.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x14gogoproto/gogo.proto\x1a\x34ibc/applications/interchain_accounts/v1/packet.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"i\n\x1cMsgRegisterInterchainAccount\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t:\x12\x82\xe7\xb0*\x05owner\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"K\n$MsgRegisterInterchainAccountResponse\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\"\xc0\x01\n\tMsgSendTx\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12_\n\x0bpacket_data\x18\x03 \x01(\x0b\x32\x44.ibc.applications.interchain_accounts.v1.InterchainAccountPacketDataB\x04\xc8\xde\x1f\x00\x12\x18\n\x10relative_timeout\x18\x04 \x01(\x04:\x12\x82\xe7\xb0*\x05owner\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"%\n\x11MsgSendTxResponse\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x32\xe7\x02\n\x03Msg\x12\xc7\x01\n\x19RegisterInterchainAccount\x12P.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccount\x1aX.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccountResponse\x12\x8e\x01\n\x06SendTx\x12=.ibc.applications.interchain_accounts.controller.v1.MsgSendTx\x1a\x45.ibc.applications.interchain_accounts.controller.v1.MsgSendTxResponse\x1a\x05\x80\xe7\xb0*\x01\x42RZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/types'
  _MSGREGISTERINTERCHAINACCOUNT._options = None
  _MSGREGISTERINTERCHAINACCOUNT._serialized_options = b'\202\347\260*\005owner\350\240\037\000\210\240\037\000'
  _MSGSENDTX.fields_by_name['packet_data']._options = None
  _MSGSENDTX.fields_by_name['packet_data']._serialized_options = b'\310\336\037\000'
  _MSGSENDTX._options = None
  _MSGSENDTX._serialized_options = b'\202\347\260*\005owner\350\240\037\000\210\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGREGISTERINTERCHAINACCOUNT._serialized_start=216
  _MSGREGISTERINTERCHAINACCOUNT._serialized_end=321
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE._serialized_start=323
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE._serialized_end=398
  _MSGSENDTX._serialized_start=401
  _MSGSENDTX._serialized_end=593
  _MSGSENDTXRESPONSE._serialized_start=595
  _MSGSENDTXRESPONSE._serialized_end=632
  _MSG._serialized_start=635
  _MSG._serialized_end=994
# @@protoc_insertion_point(module_scope)
