# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/genesis/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=ibc/applications/interchain_accounts/genesis/v1/genesis.proto\x12/ibc.applications.interchain_accounts.genesis.v1\x1a\x14gogoproto/gogo.proto\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x37ibc/applications/interchain_accounts/host/v1/host.proto\"\xe4\x01\n\x0cGenesisState\x12o\n\x18\x63ontroller_genesis_state\x18\x01 \x01(\x0b\x32G.ibc.applications.interchain_accounts.genesis.v1.ControllerGenesisStateB\x04\xc8\xde\x1f\x00\x12\x63\n\x12host_genesis_state\x18\x02 \x01(\x0b\x32\x41.ibc.applications.interchain_accounts.genesis.v1.HostGenesisStateB\x04\xc8\xde\x1f\x00\"\xc9\x02\n\x16\x43ontrollerGenesisState\x12]\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32>.ibc.applications.interchain_accounts.genesis.v1.ActiveChannelB\x04\xc8\xde\x1f\x00\x12o\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32L.ibc.applications.interchain_accounts.genesis.v1.RegisteredInterchainAccountB\x04\xc8\xde\x1f\x00\x12\r\n\x05ports\x18\x03 \x03(\t\x12P\n\x06params\x18\x04 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.ParamsB\x04\xc8\xde\x1f\x00\"\xbc\x02\n\x10HostGenesisState\x12]\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32>.ibc.applications.interchain_accounts.genesis.v1.ActiveChannelB\x04\xc8\xde\x1f\x00\x12o\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32L.ibc.applications.interchain_accounts.genesis.v1.RegisteredInterchainAccountB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04port\x18\x03 \x01(\t\x12J\n\x06params\x18\x04 \x01(\x0b\x32\x34.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00\"j\n\rActiveChannel\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12\x1d\n\x15is_middleware_enabled\x18\x04 \x01(\x08\"^\n\x1bRegisteredInterchainAccount\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tBOZMgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/genesis/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.genesis.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/genesis/types'
  _GENESISSTATE.fields_by_name['controller_genesis_state']._options = None
  _GENESISSTATE.fields_by_name['controller_genesis_state']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['host_genesis_state']._options = None
  _GENESISSTATE.fields_by_name['host_genesis_state']._serialized_options = b'\310\336\037\000'
  _CONTROLLERGENESISSTATE.fields_by_name['active_channels']._options = None
  _CONTROLLERGENESISSTATE.fields_by_name['active_channels']._serialized_options = b'\310\336\037\000'
  _CONTROLLERGENESISSTATE.fields_by_name['interchain_accounts']._options = None
  _CONTROLLERGENESISSTATE.fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000'
  _CONTROLLERGENESISSTATE.fields_by_name['params']._options = None
  _CONTROLLERGENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _HOSTGENESISSTATE.fields_by_name['active_channels']._options = None
  _HOSTGENESISSTATE.fields_by_name['active_channels']._serialized_options = b'\310\336\037\000'
  _HOSTGENESISSTATE.fields_by_name['interchain_accounts']._options = None
  _HOSTGENESISSTATE.fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000'
  _HOSTGENESISSTATE.fields_by_name['params']._options = None
  _HOSTGENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=263
  _GENESISSTATE._serialized_end=491
  _CONTROLLERGENESISSTATE._serialized_start=494
  _CONTROLLERGENESISSTATE._serialized_end=823
  _HOSTGENESISSTATE._serialized_start=826
  _HOSTGENESISSTATE._serialized_end=1142
  _ACTIVECHANNEL._serialized_start=1144
  _ACTIVECHANNEL._serialized_end=1250
  _REGISTEREDINTERCHAINACCOUNT._serialized_start=1252
  _REGISTEREDINTERCHAINACCOUNT._serialized_end=1346
# @@protoc_insertion_point(module_scope)
